# Bluebonnet

![bluebonnets in bloom](https://github.com/frank1010111/bluebonnet/raw/main/docs/_static/bluebonnets.jpg)

Bluebonnet is a library for forecasting production from hydrofactured wells.


```{toctree}
:maxdepth: 1
intro.md
fluids.ipynb
flow.ipynb
oil_flow.ipynb
forecast.ipynb
forecast_varying.ipynb
autoapi/index
contributing.md
conduct.md
background.md
changelog.md
```
